from django.db import models
from django.contrib.auth.models import AbstractUser
from ckeditor.fields import RichTextField



# Create your models here.


staff_status_opt = [
    ('Teacher', 'Teacher'),
    ('Student', 'Student')
]

class User(AbstractUser):
    user_status = models.CharField(max_length=50, verbose_name='Select', choices=staff_status_opt)


class College(models.Model):
            '''
                College name, college Logo and Color Scheme 
            '''
            college_name = models.CharField(max_length=200, blank=True, verbose_name='College Name')
            college_logo = models.ImageField(upload_to='uploads/', blank=True, verbose_name='College Logo')
            college_contact_no = models.CharField(max_length=200, blank=True, verbose_name='College Contact No')
            college_email = models.CharField(max_length=200, blank=True, verbose_name='College Email')
            college_bg_color = models.CharField(max_length=200, blank=True, verbose_name='College Background Color')
            college_fg_color= models.CharField(max_length=200, blank=True, verbose_name='College Foreground Color')
            
            class Meta:
                    verbose_name_plural = 'College'

            def __str__(self):
                    return self.college_name


class Subjects(models.Model):
            '''
                Subject Name Model, foreignkey of Student Lectures
            '''
            subject_name = models.CharField(max_length=150, blank=False, verbose_name='Subject Name')
            user_register = models.ForeignKey(User, on_delete=models.CASCADE, verbose_name='User')

            class Meta:
                        verbose_name_plural = 'Subjects'

            def __str__(self):
                return self.subject_name
                        


status_opt = [
    ('Active', 'Active'),
    ('Deactive', 'Deactive')
]

class StudentLectures(models.Model):
    lecture_subject= models.ForeignKey(Subjects, on_delete=models.CASCADE, verbose_name='Lecture Subject')
    lecture_author = models.ForeignKey(User, on_delete=models.CASCADE, verbose_name='Lecturer')
    lecture_title = models.CharField(max_length=500, verbose_name='Lecture Title')
    lecture_description= RichTextField(blank=True, verbose_name='lecture Description')
    lecture_url= models.CharField(max_length=200, verbose_name='Lecture URL')
    lecture_status= models.CharField(max_length=100, choices=status_opt, verbose_name='Lecture Status')

    created_on = models.DateTimeField(auto_now=True)
    updated_on = models.DateTimeField(auto_now_add=True)
    

    def __str__(self):
        return self.lecture_title


